pub enum NegativeToken {
MalformedJwtSegmentCount,
BadBase64UrlSegment,
InvalidJwtHeaderShape,
MissingAlg,
AlgNone,
MismatchedKid,
ExpiredClaims,
NotYetValidClaims,
BadIssuer,
BadAudience,
MalformedBearer,
NearMissApiKey,
}Expand description
Negative token shape variants for downstream parser and validator tests.
Variants
MalformedJwtSegmentCount
Emit a JWT-like value with the wrong number of dot-separated segments.
BadBase64UrlSegment
Replace one JWT segment with scanner-safe invalid base64url text.
InvalidJwtHeaderShape
Encode a JWT header that is JSON, but not a header object.
MissingAlg
Remove alg from the JWT header.
AlgNone
Set the JWT header algorithm to none.
MismatchedKid
Emit different kid values in the header and payload.
ExpiredClaims
Set an already-expired exp claim.
NotYetValidClaims
Set a future nbf claim.
BadIssuer
Replace the expected issuer claim.
BadAudience
Replace the expected audience claim.
MalformedBearer
Emit a bearer-like token that is not valid base64url.
NearMissApiKey
Emit an API-key near miss that is close to, but not, uk_test_.
Implementations
Sourceimpl NegativeToken
impl NegativeToken
Sourcepub const fn variant_name(&self) -> &'static str
pub const fn variant_name(&self) -> &'static str
Stable cache/disposition name for this negative token variant.